
[![ci](https://github.com/kmlefran/compchem-si/actions/workflows/ci.yml/badge.svg)](https://github.com/kmlefran/compchem-si/actions/workflows/ci.yml)
[![Documentation Status](https://readthedocs.org/projects/compchem-si/badge/?version=latest)](https://compchem-si.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/kmlefran/compchem-si/badge.svg?branch=main)](https://coveralls.io/github/kmlefran/compchem-si?branch=main)
[![PyPI version](https://badge.fury.io/py/compchem-si.svg)](https://badge.fury.io/py/compchem-si)
# Molecule Reorientation and .sum file handling

This package provides utilities to take Gaussian output files and generate a page containing information on the molecule. The page currently contains a visual representation of the molecule, its associated energy in Hartree, and its molecular geometry.

# Authors
Kevin Lefrancois-Gagnon
Robert C. Mawhinney

# Installation
```
pip install compchem-si
```

# Example Usage:
```python
